@@ -56,7 +56,7 @@ static void action_close_cb (GtkAction * action, PrinterQueueWindow * win);
 static void action_remove_job_cb (GtkAction * action, PrinterQueueWindow * win);
 static void action_refresh_cb (GtkAction * action, PrinterQueueWindow * win);
 
-static void icon_theme_changed_cb (XfceIconTheme * icon_theme, PrinterQueueWindow * win);
+static void icon_theme_changed_cb (GtkIconTheme * icon_theme, PrinterQueueWindow * win);
 static void tree_selection_changed_cb (GtkTreeSelection * selection, PrinterQueueWindow * win);
 static gboolean tree_button_pressed_cb (GtkWidget * widget, GdkEventButton * event, PrinterQueueWindow * win);
 static gboolean timeout_fct (PrinterQueueWindow * win);
@@ -282,7 +282,7 @@ icon_theme_update_foreach_func (GtkTreeModel * model, GtkTreePath * path, GtkTre
 }
 
 static void
-icon_theme_changed_cb (XfceIconTheme * icon_theme, PrinterQueueWindow * win)
+icon_theme_changed_cb (GtkIconTheme * icon_theme, PrinterQueueWindow * win)
 {
   PrinterQueueWindowPrivate *priv = PRINTER_QUEUE_WINDOW_GET_PRIVATE (win);
   GtkTreeModel *model;
